@@ -3,13 +3,13 @@ package Net::DNS::Parameters;
 ################################################
 ##
 ##	Domain Name System (DNS) Parameters
-##	(last updated 2024-07-22)
+##	(last updated 2025-06-16)
 ##
 ################################################
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: Parameters.pm 1982 2024-07-23 16:16:53Z willem $)[2];
+our $VERSION = (qw$Id: Parameters.pm 2017 2025-06-27 13:48:03Z willem $)[2];
 
 use integer;
 use Carp;
@@ -50,6 +50,7 @@ our %classbyname = ( '*' => 255, @classbyname );
 
 # Registry: Resource Record (RR) TYPEs
 my @typebyname = (
+	DELEG	   => 65432,					# draft-ietf-deleg
 	A	   => 1,					# RFC1035
 	NS	   => 2,					# RFC1035
 	MD	   => 3,					# RFC1035
@@ -89,7 +90,7 @@ my @typebyname = (
 	CERT	   => 37,					# RFC4398
 	A6	   => 38,					# RFC2874 RFC3226 RFC6563
 	DNAME	   => 39,					# RFC6672
-	SINK	   => 40,					# draft-eastlake-kitchen-sink
+	SINK	   => 40,					# draft-eastlake-kitchen-sink-02
 	OPT	   => 41,					# RFC3225 RFC6891
 	APL	   => 42,					# RFC3123
 	DS	   => 43,					# RFC4034
@@ -114,6 +115,9 @@ my @typebyname = (
 	ZONEMD	   => 63,					# RFC8976
 	SVCB	   => 64,					# RFC9460
 	HTTPS	   => 65,					# RFC9460
+	DSYNC	   => 66,					# RFC-ietf-dnsop-generalized-notify-09
+	HHIT	   => 67,					# draft-ietf-drip-registries-28
+	BRID	   => 68,					# draft-ietf-drip-registries-28
 	SPF	   => 99,					# RFC7208
 	UINFO	   => 100,					# IANA-Reserved
 	UID	   => 101,					# IANA-Reserved
@@ -125,7 +129,7 @@ my @typebyname = (
 	LP	   => 107,					# RFC6742
 	EUI48	   => 108,					# RFC7043
 	EUI64	   => 109,					# RFC7043
-	NXNAME	   => 128,					# draft-ietf-dnsop-compact-denial-of-existence-04
+	NXNAME	   => 128,					# RFC-ietf-dnsop-compact-denial-of-existence-07
 	TKEY	   => 249,					# RFC2930
 	TSIG	   => 250,					# RFC8945
 	IXFR	   => 251,					# RFC1995
@@ -136,10 +140,12 @@ my @typebyname = (
 	URI	   => 256,					# RFC7553
 	CAA	   => 257,					# RFC8659
 	AVC	   => 258,					#
-	DOA	   => 259,					# draft-durand-doa-over-dns
+	DOA	   => 259,					# draft-durand-doa-over-dns-02
 	AMTRELAY   => 260,					# RFC8777
 	RESINFO	   => 261,					# RFC9606
 	WALLET	   => 262,					#
+	CLA	   => 263,					# draft-johnson-dns-ipn-cla-07
+	IPN	   => 264,					# draft-johnson-dns-ipn-cla-07
 	TA	   => 32768,					# http://www.watson.org/~weiler/INI1999-19.pdf
 	DLV	   => 32769,					# RFC8749 RFC4431
 	);
@@ -195,7 +201,7 @@ our %rcodebyname = @rcodebyname;
 # Registry: DNS EDNS0 Option Codes (OPT)
 my @ednsoptionbyname = (
 	LLQ		 => 1,					# RFC8764
-	'UPDATE-LEASE'	 => 2,					# RFC-ietf-dnssd-update-lease-08
+	'UPDATE-LEASE'	 => 2,					# RFC9664
 	NSID		 => 3,					# RFC5001
 	DAU		 => 5,					# RFC6975
 	DHU		 => 6,					# RFC6975
@@ -208,9 +214,10 @@ my @ednsoptionbyname = (
 	CHAIN		 => 13,					# RFC7901
 	'KEY-TAG'	 => 14,					# RFC8145
 	'EXTENDED-ERROR' => 15,					# RFC8914
-	'CLIENT-TAG'	 => 16,					# draft-bellis-dnsop-edns-tags
-	'SERVER-TAG'	 => 17,					# draft-bellis-dnsop-edns-tags
+	'CLIENT-TAG'	 => 16,					# draft-bellis-dnsop-edns-tags-01
+	'SERVER-TAG'	 => 17,					# draft-bellis-dnsop-edns-tags-01
 	'REPORT-CHANNEL' => 18,					# RFC9567
+	ZONEVERSION	 => 19,					# RFC9660
 	'UMBRELLA-IDENT' => 20292,				# https://developer.cisco.com/docs/cloud-security/#!integrating-network-devic
 	DEVICEID	 => 26946,				# https://developer.cisco.com/docs/cloud-security/#!network-devices-getting-s
 	);
@@ -235,6 +242,7 @@ our %dnsflagbyname = @dnsflagbyname;
 # Registry: EDNS Header Flags (16 bits)
 my @ednsflagbyname = (
 	DO => 0x8000,						# RFC4035 RFC3225 RFC6840
+	CO => 0x4000,						# RFC-ietf-dnsop-compact-denial-of-existence-07
 	);
 push @ednsflagbyname, map { /^\d/ ? $_ : lc($_) } @ednsflagbyname;
 our %ednsflagbyname = @ednsflagbyname;
@@ -287,7 +295,7 @@ my @dnserrorbyval = (
 	27 => 'Unsupported NSEC3 Iterations Value',		# RFC9276
 	28 => 'Unable to conform to policy',			# draft-homburg-dnsop-codcp-00
 	29 => 'Synthesized',					# https://github.com/PowerDNS/pdns/pull/12334
-	30 => 'Invalid Query Type',				# draft-ietf-dnsop-compact-denial-of-existence-04
+	30 => 'Invalid Query Type',				# RFC-ietf-dnsop-compact-denial-of-existence-07
 	);
 our %dnserrorbyval = @dnserrorbyval;
 
@@ -450,7 +458,7 @@ Net::DNS::Parameters - DNS parameter assignments
 
 =head1 SYNOPSIS
 
-    use Net::DNS::Parameters;
+	use Net::DNS::Parameters;
 
 
 =head1 DESCRIPTION
